@@ -3,6 +3,6 @@
 export const index = 23;
 let component_cache;
 export const component = async () => component_cache ??= (await import('../entries/pages/(app)/home/_page.svelte.js')).default;
-export const imports = ["_app/immutable/nodes/23.D523KF8u.js","_app/immutable/chunks/JdJvpXsd.js","_app/immutable/chunks/IHki7fMi.js"];
+export const imports = ["_app/immutable/nodes/23.CHVC6DTv.js","_app/immutable/chunks/BsAB9Z30.js","_app/immutable/chunks/IHki7fMi.js"];
 export const stylesheets = [];
 export const fonts = [];
